import Taro from '@tarojs/taro'
import { baseUrl } from '../config'
import { logError } from '../utils/error'

export default {
  baseOptions(params, method = 'GET') {
    const { url, data } = params
    let contentType = 'application/json'
    contentType = params.contentType || contentType
    type OptionType = {
      url: string
      data?: object | string
      method?: any
      header: object
      // mode: string,
      success: any
      error: any
      xhrFields: object
    }
    const option: OptionType = {
      // 调用第三方的api把路径写全
      url: url.indexOf('http') !== -1 ? url : baseUrl + url,
      data: data,
      method: method,
      header: {
        'content-type': contentType,
        Authorization: Taro.getStorageSync('access-token')
      },
      // mode: 'cors',
      xhrFields: { withCredentials: true },
      success(res) {
        console.log('res', res)
        if (res.statusCode === '404') {
          return logError('api', '请求资源不存在')
        } else if (res.statusCode === '500') {
          return logError('api', '服务端出现了问题')
        } else if (res.statusCode === '401') {
          Taro.clearStorage()
          Taro.navigateTo({
            url: '/pages/login/login'
          })
          return logError('api', '请先登录')
        } else if (res.statusCode === '200') {
          return res.data
        }
      },
      error(e) {
        logError('api', '请求接口出现问题', e)
      }
    }
    // eslint-disable-next-line
    return Taro.request(option)
  },
  get(url: string, data?: object) {
    const option = { url, data }
    return this.baseOptions(option)
  },
  postForm: function (url: string, data: object) {
    const params = { url, data: Object.keys(data).map(key => `${key}=${data[key]}`).join('&'), contentType: 'application/x-www-form-urlencoded;charset=utf-8' }
    return this.baseOptions(params, 'POST')
  },
  post: function (url: string, data?: object, contentType?: string) {
    const params = { url, data, contentType }
    return this.baseOptions(params, 'POST')
  },
  put(url: string, data?: object) {
    const option = { url, data }
    return this.baseOptions(option, 'PUT')
  },
  delete(url: string, data?: object) {
    const option = { url, data }
    return this.baseOptions(option, 'DELETE')
  }
}
// function postForm(url, data, options) {
//   const opts = {
//     ...options,
//     method: 'POST',
//     cache: 'no-cache',
//     headers: {
//       'Content-Type': 'application/x-www-form-urlencoded;charset=utf-8'
//     },
//     body: Object.keys(data).map(key => `${key}=${data[key]}`).join('&')
//   };
//   return xFetch(url, opts);
// }

